==> zoombox-1.3.1.zip: zoombox/zoombox.php <==
<?php
/**
 * Plugin zoombox pour PluXml
 *
 * @package	PLX
 * @version	1.3.1
 * @date	16/11/2018
 * @authors	Stephane F. Maguire Cyril Ingles Thomas
 **/
class zoombox extends plxPlugin {
	/**
	 * Constructeur de la classe zoombox
	 * @param	default_lang	langue par défaut utilisée par PluXml
	 * @return	null
	 * @author	Maguire Cyril
	 **/
	public function __construct($default_lang) {
		# Appel du constructeur de la classe plxPlugin (obligatoire)
		parent::__construct($default_lang);
		# Déclarations des hooks
		if(defined('PLX_ADMIN')){
			$this->addHook('AdminTopEndHead', 'addZoomboxCss');
			$this->addHook('AdminTopEndBody', 'addZoombox');
		}else{
			$this->addHook('ThemeEndHead', 'addZoomboxCss');
			$this->addHook('ThemeEndBody', 'addZoombox');
		}
	}
	/**
	 * Méthode qui ajoute le fichier css de Zoombox
	 * @return	stdio
	 * @author	Maguire Cyril
	 **/
	public function addZoomboxCss() {?>
		<link rel="stylesheet" type="text/css" href="<?php echo PLX_PLUGINS.__CLASS__ ?>/zoombox.css" />
<?php
	}
	/**
	 * Méthode qui ajoute le fichier javascript de Zoombox
	 * @return	stdio
	 * @author	Maguire Cyril
	 **/
	public function addZoombox() {?>
		<script type="text/javascript">
			/* <![CDATA[ */
				!window.jQuery && document.write('<script type="text/javascript" src="<?php echo PLX_PLUGINS.__CLASS__ ?>/jquery-3.2.1.min.js"><\/script>');
			/* !]]> */
		</script>
		<script type="text/javascript" src="<?php echo PLX_PLUGINS.__CLASS__ ?>/zoombox.js"></script>
		<script type="text/javascript" >
			jQuery(function($){
				//$('a.zoombox').zoombox();
				// You can also use specific options
				$('a.zoombox').zoombox({
					theme       : 'darkprettyphoto', //available themes : zoombox, lightbox, prettyphoto, darkprettyphoto, simple
					opacity     : 0.8,   // Black overlay opacity
					duration    : 800,   // Animation duration
					animation   : true,  // Do we have to animate the box ?
					width       : 1000,  // Default width
					height      : 600,   // Default height
					gallery     : true,  // Allow gallery thumb view
					autoplay    : false  // Autoplay for video
				});
			});
		</script>
<?php
	}
}

==> zoombox-1.3.2.zip: zoombox/zoombox.php <==
<?php
/**
 * Plugin zoombox pour PluXml
 *
 * @package	PLX
 * @version	1.3.2
 * @date	09/01/2019
 * @authors	Stephane F. Maguire Cyril Ingles Thomas
 **/
class zoombox extends plxPlugin {
	/**
	 * Constructeur de la classe zoombox
	 * @param	default_lang	langue par défaut utilisée par PluXml
	 * @return	null
	 * @author	Maguire Cyril
	 **/
	public function __construct($default_lang) {
		# Appel du constructeur de la classe plxPlugin (obligatoire)
		parent::__construct($default_lang);
		# Déclarations des hooks
		if(defined('PLX_ADMIN')){
			$this->addHook('AdminTopEndHead', 'addZoomboxCss');
			$this->addHook('AdminTopEndBody', 'addZoombox');
		}else{
			$this->addHook('ThemeEndHead', 'addZoomboxCss');
			$this->addHook('ThemeEndBody', 'addZoombox');
		}
	}
	/**
	 * Méthode qui ajoute le fichier css de Zoombox
	 * @return	stdio
	 * @author	Maguire Cyril
	 **/
	public function addZoomboxCss() {?>
		<link rel="stylesheet" type="text/css" href="<?php echo PLX_PLUGINS.__CLASS__ ?>/zoombox.css?v=1.3.2" />
<?php
	}
	/**
	 * Méthode qui ajoute le fichier javascript de Zoombox
	 * @return	stdio
	 * @author	Maguire Cyril
	 **/
	public function addZoombox() {?>
		<script type="text/javascript">
			/* <![CDATA[ */
				!window.jQuery && document.write('<script type="text/javascript" src="<?php echo PLX_PLUGINS.__CLASS__ ?>/jquery.min.js?v=3.3.1"><\/script>');
			/* !]]> */
		</script>
		<script type="text/javascript" src="<?php echo PLX_PLUGINS.__CLASS__ ?>/zoombox.js?v=1.3.2"></script>
		<script type="text/javascript" >
			jQuery(function($){
				//$('a.zoombox').zoombox();
				// You can also use specific options
				$('a.zoombox').zoombox({
					theme       : 'darkprettyphoto', //available themes : zoombox, lightbox, prettyphoto, darkprettyphoto, simple
					opacity     : 0.8,   // Black overlay opacity
					duration    : 800,   // Animation duration
					animation   : true,  // Do we have to animate the box ?
					width       : 1000,  // Default width
					height      : 600,   // Default height
					gallery     : true,  // Allow gallery thumb view
					autoplay    : false  // Autoplay for video
				});
			});
		</script>
<?php
	}
}
